Qreu
====

.. image:: https://travis-ci.org/gisce/qreu.svg?branch=master
    :target: https://travis-ci.org/gisce/qreu

Email Wrapper to `python email module <https://docs.python.org/library/email.html>`_
